/* Copyright (C) 2003-2004, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#include "DataUpdater.hh"

#include <sstream>
#include <iomanip>

namespace wmium_gk2 {

// Reference into wmium-gk2.cc
extern int max_limit;
extern int current_usage;
extern std::string usage;
extern std::string dsl_info;
extern std::string rollover_date;
extern SampleTransformer historySamples;

extern void update_inode_dsl_label ();
extern void update_usage_label ();
extern void update_krell_max ();
extern void update_krell_value ();
extern void update_history_chart ();
// End externals

DataUpdater::DataUpdater () :
     m_dsl_text (" DSL"),
     m_dsl_speed ("????") {
}

DataUpdater::~DataUpdater () {
}

void DataUpdater::reDraw () {
  update_inode_dsl_label ();
  update_usage_label ();
  update_krell_max ();
  update_history_chart ();
}

HistoryReceiver& DataUpdater::getHistoryReceiver () {
  return *this;
}

StatusReceiver& DataUpdater::getStatusReceiver () {
  return *this;
}

void DataUpdater::setDslText (const std::string& text) {
  m_dsl_text = text;

  std::stringstream str;
  str << m_dsl_text << " " << m_dsl_speed;
  dsl_info = str.str ();
}

void DataUpdater::setErrorText (const std::string& text) {
  usage = text;
}

void DataUpdater::setSpeed (int speed) {
  std::ostringstream str;

  str << speed;
  m_dsl_speed = str.str ();

  str.str ("");
  str << m_dsl_text << " " << m_dsl_speed;
  dsl_info = str.str ();
}

void DataUpdater::setMaxLimit (int max) {
  max_limit = max;
  update_krell_max ();
}

void DataUpdater::setUsage (int used) {
  if (max_limit > 0) { // Only if not on flat rate
    std::ostringstream str;
    if (max_limit > 1000) { // use compressed format (nnnnn/nnG)
      str << std::setw (5) << std::setfill (' ') << used;
      str << "/" << std::setw (2) << std::setfill (' ');
      str << (max_limit / 1000) << "G";
    }
    else { // use old format (nnnn/nnnn)
      str << std::setw (4) << std::setfill (' ') << used;
      str << "/" << std::setw (4) << std::setfill (' ') << max_limit;
    }
    usage = str.str ();

    current_usage = used;
    update_krell_value ();
  }
}

void DataUpdater::setRollingUsage (int used) {
  if (max_limit == 0) { // Only if on flat rate
    std::ostringstream str;
    str << "FR:" << std::setw (6) << std::setfill (' ') << used;
    usage = str.str ();

    current_usage = 0;
    // no update of krell, since krell not in use for flatrate
  }
}

void DataUpdater::setRollOverDate (int day, int month) {
  std::ostringstream str;
  str << "RO: " << std::setw (2) << std::setfill ('0') << day;
  str << "/" << std::setw (2) << std::setfill ('0') << month;
  rollover_date = str.str ();
}

void DataUpdater::setGraphData (const SampleVector& data) {
  historySamples.setSampleVector (data);
}

} // end namespace
