/* Copyright (C) 2003, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#include "NetworkManager.hh"

namespace wmium_gk2 {

NetworkManager::NetworkManager (PanelHandler& panelHandler)
  : m_fdSet (),
    m_usageDataHandler (panelHandler),
    m_speedDataHandler (panelHandler),
    m_historyDataHandler (panelHandler) {

}

NetworkManager::~NetworkManager () {
  delete m_statsFetcher;
}

void NetworkManager::setLoginDetails (
    const std::string *username,
    const std::string *password,
    const std::string *hostname,
    const std::string *url) {

  if (m_statsFetcher) delete m_statsFetcher;

  m_statsFetcher = new StatsFetcher (
      m_fdSet,
      *username,
      *password,
      *hostname,
      *url,
      m_usageDataHandler,
      m_speedDataHandler,
      m_historyDataHandler,
      false);
}

void NetworkManager::queueNewRequests () {
  if (!m_statsFetcher) return;

  m_statsFetcher->queueUsageCheck ();
  m_statsFetcher->queueSpeedCheck ();
  m_statsFetcher->queueHistoryCheck ();
}

void NetworkManager::processNetworkData () {
  if (m_fdSet.checkForEvent (false)) {
    m_statsFetcher->processNetworkEvent ();
  }
}

} // end namespace
