/* Copyright (C) 2002-2005, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#include "CommandLine.hh"

#include <unistd.h>
#include <stdlib.h>

using std::string;

/**
 * Fills in the <code>opts</code> parameter with the values parsed from
 * the commandline.
 *
 * The <code>opts</code> struct is reset to defaults before parsing is
 * started, so it will always be modified, even if the function aborts
 * due to incorrect command line options.
 *
 * @param argc The argc from main().
 * @param argv The argv from main().
 * @param opts The structure to be modified to reflect the command line options.
 * @return True if commandline is parsed successfully, false otherwise.
 */
bool parseCommandLine (int argc, char *argv[], CommandLineOptions& opts) {
  int flagChar;

  opts.printHelp = false;
  opts.quietMode = false;
  opts.alternateDate = false;
  opts.snoopData = false;
  opts.initialPanel = 's';
  opts.initialGraphMode = 'm';
  opts.rcFile = string (getenv ("HOME")) + "/.wmiumrc";

  while ((flagChar = getopt (argc, argv, "dhqsp:g:f:")) != -1) {
    switch (flagChar) {
      case 'd': opts.alternateDate = true; break;
      case 'h': opts.printHelp = true; break;
      case 'q': opts.quietMode = true; break;
      case 's': opts.snoopData = true; break;
      case 'p': {
        if (*optarg != 's' && *optarg != 'g') return false;
        opts.initialPanel = *optarg;
        break;
      }
      case 'g': {
        switch (*optarg) {
          case 'w': // fall
          case 'm': // fall
          case 'q': // fall
          case 'y': opts.initialGraphMode = *optarg; break;
          default: return false;
        }
        break;
      }
      case 'f': opts.rcFile = optarg; break;
      default: return false;
    }
  }

  return true;
}

