/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#include "ERegEx.hh"
#include <stdexcept>

using std::invalid_argument;
using std::string;

/**
 * Prepares (compiles) an extended regular expression for use.
 *
 * @param exp The regular expression to compile.
 * @exception invalid_argument If <code>exp</code> is an invalid RE.
 */
ERegEx::ERegEx (const string& exp) {
  int err = regcomp (&m_regex, exp.c_str (), REG_EXTENDED | REG_NOSUB);
  if (err) throw invalid_argument ("invalid regex");
}

/**
 * Frees the memory used by this regular expression.
 */
ERegEx::~ERegEx () {
  regfree (&m_regex);
}

/**
 * Checks whether <code>str</code> matches this regular expression.
 *
 * @param str The string to check if is a match.
 * @returns True if is a match, False otherwise.
 */
bool ERegEx::isMatch (const string& str) const {
  return regexec (&m_regex, str.c_str (), 0, 0, 0) == 0;
}
