/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#ifndef FDMANAGER_HH
#define FDMANAGER_HH

/**
 * Mediator class to store and relay information needed to select() properly.
 *
 * Provides a layer of separation to enable decoupling of highlevel and
 * lowlevel classes. Lowlevel classes can flag the conditions they want checked,
 * and highlevel classes can then do the checking (via select()) without
 * explicitly knowing what and why something is checked for.
 *
 * Checks for the exceptional state is not supported, but could easily be
 * added if needed.
 */
class FDHolder {
  public:
    FDHolder ();
    explicit FDHolder (int fd);
    ~FDHolder ();

    int getFD ();
    void resetFD (int fd);
    bool isValidFD () const;

    bool wantRead () const;
    bool wantWrite () const;

    bool canRead () const;
    bool canWrite () const;

    bool hasEvent () const;

    void setReadWanted (bool yes);
    void setWriteWanted (bool no);

  private:
    FDHolder (const FDHolder&);
    FDHolder& operator = (const FDHolder&);

    int m_fd;
    bool m_read;
    bool m_write;
};

#endif
