/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#ifndef HISTORYPAINTER_HH
#define HISTORYPAINTER_HH

#include "HistoryReceiver.hh"
#include "WMDockWindow.hh"
#include "XpmCharSetLCD6x8.hh"
#include "XpmField.hh"
#include "XpmGraphField.hh"
#include "SampleTransformer.hh"

typedef enum { GRAPHWEEK, GRAPHMONTH, GRAPHQUARTER, GRAPHYEAR } GraphMode;

/**
 * Class responsible for painting the history graph panel.
 */
class HistoryPainter : public HistoryReceiver {
  public:
    HistoryPainter (Display& dpy, WMDockWindow& window);
    virtual ~HistoryPainter ();

    void setMode (GraphMode mode);
    GraphMode getMode () const;

    virtual void setGraphData (const SampleVector& data);

    bool isInModeChangeArea (int x, int y);

    void resetMask ();
    void reDraw ();

  private:
    HistoryPainter (const HistoryPainter&);
    HistoryPainter* operator = (const HistoryPainter&);

    void updateMode ();
    void updatePeakValue ();

    Display& m_display;
    WMDockWindow& m_window;
    XpmCharSetLCD6x8 m_charset;
    XpmField m_peak;
    XpmField m_modeIndicator; // W, M, Q, Y
    XpmGraphField m_graph;
    Pixmap m_mask;
    SampleTransformer m_dataTransformer;
    GraphMode m_mode;
};

#endif
