/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#ifndef PANELSELECTOR_HH
#define PANELSELECTOR_HH

#include "PanelHandler.hh"
#include "StatusPainter.hh"
#include "HistoryPainter.hh"

typedef enum { STATUSPANEL, HISTORYPANEL } PanelChoice;

/**
 * Controlling class for the status and history panels.
 *
 * Enables switching between the different panels, and ensures proper repainting
 * of the current panel. Also handles the switching between the various history
 * graphs, with support from the actual HistoryPainter.
 *
 * @see HistoryPainter
 */
class PanelSelector : public PanelHandler {
  public:
    PanelSelector (Display& dpy, WMDockWindow& window, bool status = true);
    virtual ~PanelSelector ();

    void selectPanel (PanelChoice choice);
    void selectNextPanel ();
    virtual void reDraw ();

    void processClick (int x, int y, bool reverse);

    virtual HistoryReceiver& getHistoryReceiver ();
    virtual StatusReceiver& getStatusReceiver ();

    HistoryPainter& getHistoryPainter ();
    StatusPainter& getStatusPainter ();

  private:
    PanelSelector (const PanelSelector&);
    PanelSelector& operator = (const PanelSelector&);

    StatusPainter m_statusPainter;
    HistoryPainter m_historyPainter;
    bool m_statusActive;
};

#endif
