/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#ifndef SSLCLIENTSOCKET_HH
#define SSLCLIENTSOCKET_HH

#include "FDHolder.hh"
#include "SSL_CTXPtr.hh"
#include "SSLPtr.hh"
#include <string>

/**
 * Socket with SSL layer operating only in client mode with transparent
 * SSL/TLS negotiation.
 *
 * Relies on the OpenSSL library for all things SSL.
 */
class SSLClientSocket {
  public:
    SSLClientSocket (const std::string& host, short port);
    ~SSLClientSocket ();

    FDHolder& getFDHolder ();
    int read (std::string& data);
    int write (std::string& data);

    bool isReadEOF ();
    bool isWriteEOF ();

  private:
    SSLClientSocket (const SSLClientSocket&);
    SSLClientSocket& operator = (const SSLClientSocket&);

    int m_fd;
    FDHolder m_fdh;
    SSL_CTXPtr m_ctx;
    SSLPtr m_ssl;
    bool m_readEOF;
    bool m_writeEOF;
};

#endif
