/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#ifndef SAMPLETRANSFORMER_HH
#define SAMPLETRANSFORMER_HH

#include <vector>

typedef std::vector<double> SampleVector;

/**
 * Data transformation class to process the history data into a format directly
 * useable by the history graph panel.
 */
class SampleTransformer {
  public:
    SampleTransformer ();
    ~SampleTransformer ();

    void setSampleVector (const SampleVector& newData);

    void setIncludeSize (int size);
    void setOutputVectorSize (int size);
    void setNormalizationLevel (int maxValue, int maxPercentage = 98);

    const SampleVector& getOutputVector () const;
    double getPeakValue () const; // pre-normalization peak value

  private:
    SampleTransformer (const SampleTransformer&);
    SampleTransformer& operator = (const SampleTransformer&);

    void updateOutputVector ();
    void createAdjustedInputData (SampleVector& resultData) const;
    void normalizeOutputVector ();

    SampleVector m_inputSamples;
    SampleVector m_outputSamples;
    int m_includeSize;
    int m_outputVectorSize;
    int m_normalizationMax;
    int m_normalizationPercentage;
};

#endif
