/* Copyright (C) 2002-2005, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#ifndef STATSFETCHER_HH
#define STATSFETCHER_HH

#include <string>

class FDSet;
class DataHandler;
class Request;
class SSLClientSocket;

/**
 * High level interface for queueing update requests and respond to network
 * events for said requests.
 */
class StatsFetcher {
  public:
    StatsFetcher (FDSet& fdSet, const std::string& username,
                  const std::string& password, const std::string& host,
                  const std::string& url, DataHandler& usage,
                  DataHandler& speed, DataHandler& history, bool snoop);
    ~StatsFetcher ();

    void queueUsageCheck (bool update = false);
    void queueSpeedCheck (bool update = false);
    void queueHistoryCheck (bool update = false);

    void processNetworkEvent ();

  private:
    StatsFetcher (const StatsFetcher&);
    StatsFetcher& operator = (const StatsFetcher&);

    void clearUsageRequest ();
    void clearSpeedRequest ();
    void clearHistoryRequest ();

    SSLClientSocket *createSSLSocket ();
    std::string buildBasicDataString ();
    std::string buildRequestString (const std::string& data);

    FDSet& m_fdSet;

    std::string m_username;
    std::string m_password;
    std::string m_host;
    std::string m_url;

    DataHandler& m_usageHandler;
    DataHandler& m_speedHandler;
    DataHandler& m_historyHandler;

    Request *m_usageRequest;
    Request *m_speedRequest;
    Request *m_historyRequest;

    bool m_snoop;
};

#endif
