/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#include "XpmCharSetLCD6x8.hh"
#include "WMDockWindow.hh"

#include "xpm/charset.xpm"
#include <new>

using std::bad_alloc;
using std::string;

/**
 * Creates an LCD 6x8 charset ready for use, tied to the given X display.
 *
 * @param dpy The X Display to create this LCD charset for.
 * @exception bad_alloc If the charset cannot be created.
 */
XpmCharSetLCD6x8::XpmCharSetLCD6x8 (Display& dpy)
  : m_display (dpy)
{
  if (XpmCreatePixmapFromData (&dpy, XDefaultRootWindow (&dpy), charset_xpm,
      &m_xpm, 0, 0) != XpmSuccess) throw bad_alloc ();
}

/**
 * Destroys the object and frees resources used.
 */
XpmCharSetLCD6x8::~XpmCharSetLCD6x8 () {
  XFreePixmap (&m_display, m_xpm);
}

/**
 * Draws the given string onto the WMDockWindow specified, at the given
 * coordinates.
 *
 * Characters less than 0x20 and greater than 0x60 are silently ignored.
 *
 * @param window The WMDockWindow to draw the text on.
 * @param x The X coordinate of the WMDockWindow to draw the text at.
 * @param y The Y coordinate of the WMDockWindow to draw the text at.
 * @param text The text to draw.
 */
void XpmCharSetLCD6x8::drawString (WMDockWindow& window, int x, int y,
    const string& text)
{
  int i = 0;
  int len = text.length ();
  while (i < len) {
    char c = text[i++];
    if (c < 0x20 || c >= 0x60) continue; // unprintable, ignore

    // calculate cell in pixmap
    c -= 0x20;
    int col = c % 0x10; // char col 0 - 15
    int row = c / 0x10; // char row 0 - 3

    // convert cell to pixel values
    col *= 6;
    row *= 8;

    // draw it
    window.drawXpmAt (m_xpm, col +1, row, 6, 8, x, y);
    x += 6;
  }
}
