/* Copyright (C) 2002, Johny Mattsson
 *
 * This code is licenced under the GNU General Public Licence version 2.
 * See the file COPYING for details.
 */

#include "XpmField.hh"
#include <new>

using std::bad_alloc;
using std::string;

/**
 * Initializes the object and ties it to the given Display and window.
 *
 * @param dpy The X Display to tie this object to.
 * @param window The WMDockWindow this field should appear on.
 * @param charset The character set to use for drawing text.
 * @param x The X coordinate on the WMDockWindow where the field should be.
 * @param y The Y coordinate on the WMDockWindow where the field should be.
 * @param xpmData The XPM data to use for field background. Field size
 *     information is extracted from this data.
 * @exception bad_alloc If something cannot be allocated.
 */
XpmField::XpmField (
    Display& dpy,
    WMDockWindow& window,
    XpmCharSetLCD6x8& charset,
    int x,
    int y,
    char **xpmData)
  : m_display (dpy), m_window (window), m_charset(charset), m_x (x), m_y (y),
    m_frameX (0), m_frameY (0)
{
  XpmAttributes attribs;
  attribs.valuemask = XpmSize;

  if (XpmCreatePixmapFromData (&dpy, XDefaultRootWindow (&dpy), xpmData,
      &m_frame, 0, &attribs) != XpmSuccess) {
    throw bad_alloc ();
  }

  m_frameX = attribs.width;
  m_frameY = attribs.height;
}

/**
 * Destroys the object and frees resources used.
 */
XpmField::~XpmField () {
  XFreePixmap (&m_display, m_frame);
}

/**
 * Sets the text to be displayed in this field.
 *
 * @param text The new text to be displayed.
 */
void XpmField::setText (const string& text) {
  m_text = text;
}

/**
 * Redraws this field onto the associated window.
 */
void XpmField::reDraw () {
  m_window.drawXpmAt (m_frame, 0, 0, m_frameX, m_frameY, m_x, m_y);
  m_charset.drawString (m_window, m_x + 1, m_y + 1, m_text);
}

